@@ -19,23 +19,21 @@
 
 
 (declare-top (special poport fortlinelen* fortcurrind* ratlinelen*
-	ratcurrind* clinelen* ccurrind* *cr* piport
-	*errin* *errout* *slash*))
+	ratcurrind* clinelen* ccurrind* *cr* *slash*))
 ;;                                        ;;
 ;;  code formatting & printing functions  ;;
 ;;                                        ;;
 
+;;  princ with case inverted
+(defun princ-invert-case (sym)
+  (princ (print-invert-case sym)))
 
 ;;  fortran code formatting & printing functions  ;;
 
 (defun formatfort (lst)
-  (prog (ch)
-	(setq ch (wrs nil))
-	(foreach c in *outchanl* do
-		 (progn
-		  (wrs c)
-		  (formatfort1 lst)))
-	(wrs ch)))
+  (foreach c in *outchanl* do
+     (let ((*standard-output* c))
+       (formatfort1 lst))))
 
 (defun formatfort1 (lst)
   (foreach elt in lst do
@@ -45,7 +43,7 @@
 		  (progn
 		   (cond ((> (+ (posn) (length (explode2 elt))) fortlinelen*)
 			  (fortcontline)))
-		   (princ elt))))))
+		   (princ-invert-case elt))))))
 
 (defun fortcontline ()
   (progn
@@ -62,13 +60,9 @@
 ;;  ratfor code formatting & printing functions  ;;
 
 (defun formatrat (lst)
-  (prog (ch)
-	(setq ch (wrs nil))
-	(foreach c in *outchanl* do
-		 (progn
-		  (wrs c)
-		  (formatrat1 lst)))
-	(wrs ch)))
+  (foreach c in *outchanl* do
+     (let ((*standard-output* c))
+       (formatrat1 lst))))
 
 (defun formatrat1 (lst)
   (foreach elt in lst do
@@ -79,7 +73,7 @@
 		   (cond ((> (+ (posn) (length (explode2 elt)))
 				    ratlinelen*)
 			  (ratcontline)))
-		   (princ elt))))))
+		   (princ-invert-case elt))))))
 
 (defun ratcontline ()
   (progn
@@ -95,13 +89,9 @@
 ;;  c code formatting & printing functions  ;;
 
 (defun formatc (lst)
-  (prog (ch)
-	(setq ch (wrs nil))
-	(foreach c in *outchanl* do
-		 (progn
-		  (wrs c)
-		  (formatc1 lst)))
-	(wrs ch)))
+  (foreach c in *outchanl* do
+     (let ((*standard-output* c))
+       (formatc1 lst))))
 
 (defun formatc1 (lst)
   (foreach elt in lst do
@@ -112,7 +102,7 @@
 		   (cond ((> (+ (posn) (length (explode2 elt)))
 				    clinelen*)
 			  (ccontline)))
-		   (princ elt))))))
+		   (princ-invert-case elt))))))
 
 (defun ccontline ()
   (progn
@@ -132,14 +122,9 @@
 
 
 (defun pprin2 (arg)
-  (let ((ch (wrs nil)))
-       (cond ((eq arg *cr*)
-	      (foreach c in *outchanl* do
-		       (progn (wrs c) (terpri))))
-	     (t
-	      (foreach c in *outchanl* do
-		       (progn (wrs c) (princ arg)))))
-       (wrs ch)))
+  (if (eq arg *cr*)
+      (foreach c in *outchanl* do (terpri c))
+      (foreach c in *outchanl* do (princ arg c))))
 
 
 ;;                 ;;
@@ -148,11 +133,13 @@
 
 
 ;;  error & warning message printing routine  ;;
+(defun gentranerr( msgtype exp msg1 msg2)
+  (if (eq msgtype 'e) ($error exp msg1 msg2) (mtell exp msg1 msg2)))
 
-(defun gentranerr (msgtype exp msg1 msg2)
+#+nil(defun gentranerr (msgtype exp msg1 msg2)
   (prog (holdich holdoch c)
-	(setq holdich (rds *errin*))
-	(setq holdoch (wrs *errout*))
+	(setq holdich (rds *standard-input*))
+	(setq holdoch (wrs *error-output*))
 	(terpri)
 	(cond (exp
 	       (prettyprint exp)))
@@ -166,13 +153,10 @@
 	(terpri)
 	(cond (msg2
 	       (repeat
-		(cond ((not (member c (list '| |  *cr*)))
-		       (progn
-			(terpri)
-			(princ "    ")
-			(princ msg2)
-			(princ (concat (concat " (y" *slash*) "n)  ")))))
-		(member (setq c (readc)) '(y y n n)))))
+		(unless (member c (list '| |  *cr*))
+		  (format t  "~%    ~a" msg2)
+		  (format t " (y~an)  " *slash*))
+		(member (setq c (read-char t nil nil)) '(y y n n)))))
 	(wrs holdoch)
 	(rds holdich)
 	(cond ((member c '(n n))
