@@ -52,7 +52,8 @@
       (terpri)
       (if help-string
 	  (format t "        ~a" help-string))
-      (terpri))))
+      (terpri)))
+  (force-output))
 
 ;; Old argument processing.  Leaving this here for now, but if getopts
 ;; works well enough, then these should be removed.
