@@ -53,8 +53,6 @@
 	   tanh cosh sinh tan  ;(trigi): same, could remove from trigi
 	   break		     ; special variable in displa.lisp
 	   gcd				; special in rat module
-	   ;; (getalias '$lambda) => cl:lambda, which implies that
-	   ;; Maxima parses lambda as cl:lambda. 
 	   #+(and sbcl sb-package-locks) makunbound)
   #+gcl
   (:import-from :system
@@ -319,7 +317,10 @@
 			  #:coerce
 			  )
   (:export #:lentz
-	   #:sum-power-series))
+	   #:sum-power-series
+	   #:format-e
+	   #:format-f
+	   #:format-g))
 
 ;; Export all the external symbols in BIGFLOAT-IMPL from BIGFLOAT too.
 (do-external-symbols (s '#:bigfloat-impl)
@@ -344,6 +345,11 @@
   (pushnew 'lock-maxima-packages ext:*after-save-initializations*))
 
 
+;; Some versions of CMUCL already have a compatible version of INTL,
+;; so skip it if we have it.  CMUCL will already define the INTL
+;; package correctly.
+
+#+#.(cl:if (cl:and (cl:member :cmu cl:*features*) (cl:find-package '#:intl))  '(or) '(and))
 (defpackage :intl
   (:use :common-lisp)
   (:export #:setlocale #:textdomain #:gettext #:dgettext
@@ -354,4 +360,9 @@
   #+gcl
   (:shadowing-import-from #:system #:define-compiler-macro))
 
+;; (getalias '$lambda) => CL:LAMBDA, which implies that Maxima parses lambda as CL:LAMBDA.
+;; Unlocking the :common-lisp package seems to be the simplest way to avoid an error.
+;; (Shadowing LAMBDA causes errors and removing the alias causes some other errors. Oh well.)
+#+(and sbcl sb-package-locks) (sb-ext:unlock-package :common-lisp)
+
 (provide :maxima)
