@@ -181,8 +181,10 @@ is EQ to FNNAME if the latter is non-NIL."
 	(decf mlambda-pointer 5)))))
 
 (defun mlambda (fn args fnname noeval form)
-  (cond ((not ($listp (cadr fn)))
-	 (merror (intl:gettext "lambda: first argument must be a list; found: ~M") (cadr fn))))
+  ; We assume that the lambda expression handed to us has been simplified,
+  ; or at least that it's well-formed.  This is because various checks are
+  ; performed during simplification instead of every time lambda expressions
+  ; are applied to arguments.
   (setq noevalargs nil)
   (let ((params  (cdadr fn))( mlocp  t))
     (setq loclist (cons nil loclist))
@@ -321,9 +323,9 @@ is EQ to FNNAME if the latter is non-NIL."
          (setq u
                (or (safe-getl (caar form) '(noun))
                    (and *nounsflag*
-                        (and (symbolp (caar form)) (eql (getcharn (caar form) 1) #\%))
+                        (and (symbolp (caar form)) (char= (get-first-char (caar form)) #\%))
                         (not (or (getl-lm-fcn-prop (caar form) '(subr))
-                                 (safe-getl (caar form) '(mfexpr*))))
+                              (safe-getl (caar form) '(mfexpr*))))
                         (prog2 ($verbify (caar form))
                                (safe-getl (caar form) '(noun))))
                    (and (not aryp)
@@ -338,7 +340,7 @@ is EQ to FNNAME if the latter is non-NIL."
                                        (not (safe-mget (caar form) 'local-fun))
                                        (setq transp t)
                                        (caar form))))
-                        (getl-lm-fcn-prop u '(subr)))
+                        (getl-lm-fcn-prop u '(subr mfexpr)))
                    (cond (aryp (safe-mgetl (caar form) '(hashar array)))
                          ((safe-mgetl (caar form) '(mexpr mmacro)))
                          (t
@@ -371,6 +373,8 @@ is EQ to FNNAME if the latter is non-NIL."
                  ((eq (car u) 'mfexpr*)
                   (setq noevalargs nil)
                   (apply (cadr u) (ncons form)))
+                 ((eq (car u) 'mfexpr)
+                  (mlambda (cadr u) (cdr form) (caar form) noevalargs form))
                  ((eq (car u) 'macro)
                   (setq noevalargs nil)
                   (setq form (cons(caar form) (cdr form)))
@@ -420,7 +424,9 @@ is EQ to FNNAME if the latter is non-NIL."
 	((setq fn (symbol-array sym))
 	 (setq typ 'array))
 	((setq fn (get sym 'mfexpr*))
-	 (setq typ 'mfexpr*)))
+	 (setq typ 'mfexpr*))
+	((setq fn (get sym 'mfexpr))
+	 (setq typ 'mfexpr)))
   (and typ (member typ props :test #'eq) (list typ fn)))
 
 
@@ -434,12 +440,16 @@ is EQ to FNNAME if the latter is non-NIL."
 	  (nosimp (if aryp new (cons (cons (caar new) '(simp)) newargs)))
 	  (t (cons (cons (caar new) aryp) newargs)))))
 
+(defun mparam (var)
+  (cond ((atom var)
+         var)
+        ((atom (cadr var))
+         (cadr var))
+        (t
+         (cadadr var))))
+
 (defun mparams (vars)
-  (mapcar #'(lambda (x)
-	      (cond ((atom x) x)
-		    ((atom (cadr x)) (cadr x))
-		    (t (cadadr x))))
-	  (cdr vars)))
+  (mapcar #'mparam (cdr vars)))
 
 (defmfun mop (form)
   (if (eq (caar form) 'mqapply)
@@ -452,10 +462,12 @@ is EQ to FNNAME if the latter is non-NIL."
       (cdr form)))
 
 (defun badfunchk (name val flag)
+  (declare (special aryp))
   (if (or flag (numberp val) (member val '(t nil $%e $%pi $%i) :test #'eq))
-      (if (and (atom name) (not (equal val name)))
-        (merror (intl:gettext "apply: found ~M evaluates to ~M where a function was expected.") name val)
-        (merror (intl:gettext "apply: found ~M where a function was expected.") val))))
+      (let ((type (if aryp (intl:gettext "an array") (intl:gettext "a function"))))
+        (if (and (atom name) (not (equal val name)))
+            (merror (intl:gettext "apply: found ~M evaluates to ~M where ~M was expected.") name val type)
+            (merror (intl:gettext "apply: found ~M where ~M was expected.") val type)))))
 
 ;; To store the value of $errormsg in mbind. This value is looked up in the
 ;; routine mbind-doit. This is a hack to get the expected behavior, when the
@@ -1071,7 +1083,7 @@ wrapper for this."
 	     (meval exp)
 	     (list (car exp) (cadr exp) (caddr exp)
 		   (mevalatoms (cadddr exp)) (mevalatoms (car (cddddr exp))))))
-	((and (eq (caar exp) '$%th) (eq (ml-typep (simplify (cadr exp))) 'fixnum))
+	((and (eq (caar exp) '$%th) (fixnump (simplify (cadr exp))))
 	 (meval1 exp))
 	((prog2 (autoldchk (caar exp))
 	     (and (getl (caar exp) '(mfexpr*))
@@ -1256,7 +1268,8 @@ wrapper for this."
        (nreverse ans))))
 
 (defun mapatom (x)
-  (or (symbolp x) (mnump x) ($subvarp x) (stringp x)))
+  (or (symbolp x) (mnump x) ($subvarp x) (stringp x)
+      (and (consp x) (eq (caar x) 'mminus) (mnump (cadr x)))))
 
 (defmfun $mapatom (x)
   (if (mapatom (specrepcheck x)) t))
@@ -1429,31 +1442,30 @@ wrapper for this."
 
 (defun declare1 (vars val prop mpropp)
   (dolist (var vars)
-    (setq var (getopr var))
     (unless (or (symbolp var) (stringp var))
       (merror (intl:gettext "declare: argument must be a symbol or a string; found: ~M") var))
-    (cond ((eq mpropp 'kind) (declarekind var prop))
-	  ((eq mpropp 'opers)
-	   (putprop (setq var (linchk var)) t prop) (putprop var t 'opers)
-	   (if (and (symbolp var) (not (get var 'operators)))
-         (putprop var 'simpargs1 'operators)))
 
-	  ((eq mpropp '$alphabetic)
-       ; Explode var into characters and put each one on the *alphabet* list,
-       ; which is used by src/nparse.lisp .
-       (dolist (1-char (coerce var 'list))
-         (add2lnc 1-char *alphabet*)))
-
-	  (mpropp
-	   (if (and (member prop '($scalar $nonscalar) :test #'eq)
-		    (mget var (if (eq prop '$scalar) '$nonscalar '$scalar)))
-	       (merror (intl:gettext "declare: inconsistent declaration ~:M") `(($declare) ,var ,prop)))
-	   (mputprop var val prop))
-	  (t (putprop var val prop)))
-    (if (and (safe-get var 'op) (operatorp1 var)
-	     (not (member (setq var (get var 'op)) (cdr $props) :test #'eq)))
-	(setq *mopl* (cons var *mopl*)))
-    (add2lnc (getop var) $props)))
+      (if (eq mpropp '$alphabetic)
+        ; Explode var into characters and put each one on the *alphabet* list,
+        ; which is used by src/nparse.lisp .
+        (dolist (1-char (coerce var 'list))
+          (add2lnc 1-char *alphabet*))
+        (progn
+          (setq var (getopr var))
+          (cond
+            ((eq mpropp 'kind) (declarekind var prop))
+            ((eq mpropp 'opers)
+             (putprop (setq var (linchk var)) t prop) (putprop var t 'opers))
+            (mpropp
+              (if (and (member prop '($scalar $nonscalar) :test #'eq)
+                       (mget var (if (eq prop '$scalar) '$nonscalar '$scalar)))
+                (merror (intl:gettext "declare: inconsistent declaration ~:M") `(($declare) ,var ,prop)))
+              (mputprop var val prop))
+            (t (putprop var val prop)))
+          (if (and (safe-get var 'op) (operatorp1 var)
+                   (not (member (setq var (get var 'op)) (cdr $props) :test #'eq)))
+            (setq *mopl* (cons var *mopl*)))
+          (add2lnc (getop var) $props)))))
 
 (defun linchk (var)
   (if (member var '($sum $integrate $limit $diff $transpose) :test #'eq)
@@ -1482,7 +1494,7 @@ wrapper for this."
 	  ((eq (cadr l) '$array) (meval `(($remarray) ,@vars)))
 	  ((member (cadr l) '($alias $noun) :test #'eq) (remalias1 vars (eq (cadr l) '$alias)))
 	  ((eq (cadr l) '$matchdeclare) (remove1 vars 'matchdeclare t t nil))
-	  ((eq (cadr l) '$rule) (remrule vars))
+	  ((eq (cadr l) '$rule) (remrule (mapcar #'(lambda (v) (if (stringp v) ($verbify v) v)) vars)))
 	  ((member (cadr l) '($evfun $evflag $nonarray $bindtest
 			    $autoload $assign) :test #'eq)
 	   (remove1 vars (stripdollar (cadr l)) nil t nil))
@@ -1517,44 +1529,46 @@ wrapper for this."
 
 (defmfun remove1 (vars prop mpropp info funp)
   (do ((vars vars (cdr vars)) (allflg))
-      ((null vars))
+    ((null vars))
     (unless (or (symbolp (car vars)) (stringp (car vars)))
       (merror (intl:gettext "remove: argument must be a symbol or a string; found: ~M") (car vars)))
-    (cond ((and (eq (car vars) '$all) (null allflg))
-	   (setq vars (append vars (cond ((atom info) (cdr $props))
-					 (funp (mapcar #'caar (cdr info)))
-					 (t (cdr info))))
-		 allflg t))
-	  (t
+    (cond
+      ((and (eq (car vars) '$all) (null allflg))
+       (setq vars (append vars (cond ((atom info) (cdr $props))
+                                     (funp (mapcar #'caar (cdr info)))
+                                     (t (cdr info))))
+             allflg t))
+      (t
         (if (and (stringp (car vars)) (eq prop '$op) (getopr0 (car vars)))
           (kill-operator (getopr0 (car vars))))
 
-	   (let ((var  (getopr (car vars)))( flag  nil))
-	     (cond (mpropp (mremprop var prop)
-			   (when (member prop '(mexpr mmacro) :test #'eq)
-			     (mremprop var 'mlexprp)
-			     (mremprop var 'mfexprp)
-			     (remprop var 'lineinfo)
-			     (if (mget var 'trace)
-				 (macsyma-untrace var))))
-		   ((and (eq prop '$alphabetic) (stringp var))
-	    (dolist (1-char (coerce var 'list))
-	      (setf *alphabet* (delete 1-char *alphabet* :count 1 :test #'equal))))
-		   ((eq prop '$transfun)
-		    (remove-transl-fun-props var)
-		    (remove-transl-array-fun-props var))
-		   ((or (setq flag (member prop (cdr $features) :test #'eq)) (member prop opers :test #'eq))
-		    (if flag (unkind var prop))
-		    (zl-remprop var prop)
-		    (if (not (getl var (delete prop (copy-list opers) :count 1 :test #'eq)))
-			(zl-remprop var 'opers)))
-		   (t (zl-remprop var prop)))
-	     (cond ((eq info t) (rempropchk var))
-		   ((eq info 'foo))
-		   (funp
-		    (mfunction-delete var info))
-		   (t
-		    (setf info (delete var info :count 1 :test #'eq)))))))))
+        (if (and (eq prop '$alphabetic) (stringp (car vars)))
+          (dolist (1-char (coerce (car vars) 'list))
+            (setf *alphabet* (delete 1-char *alphabet* :count 1 :test #'equal)))
+          (let ((var  (getopr (car vars)))( flag  nil))
+            (cond
+              (mpropp (mremprop var prop)
+                      (when (member prop '(mexpr mmacro) :test #'eq)
+                        (mremprop var 'mlexprp)
+                        (mremprop var 'mfexprp)
+                        (remprop var 'lineinfo)
+                        (if (mget var 'trace)
+                          (macsyma-untrace var))))
+              ((eq prop '$transfun)
+               (remove-transl-fun-props var)
+               (remove-transl-array-fun-props var))
+              ((or (setq flag (member prop (cdr $features) :test #'eq)) (member prop opers :test #'eq))
+               (if flag (unkind var prop))
+               (zl-remprop var prop)
+               (if (not (getl var (delete prop (copy-list opers) :count 1 :test #'eq)))
+                 (zl-remprop var 'opers)))
+              (t (zl-remprop var prop)))
+            (cond ((eq info t) (rempropchk (car vars)))
+                  ((eq info 'foo))
+                  (funp
+                    (mfunction-delete var info))
+                  (t
+                    (setf info (delete var info :count 1 :test #'eq))))))))))
 
 (defun remove-transl-fun-props (fun)
   (if (mget fun 'trace)
@@ -1731,7 +1745,9 @@ wrapper for this."
 
 (defmspec $array (x)
   (setq x (cdr x))
-  (cond ($use_fast_arrays
+  (cond
+	((symbolp (car x))
+     (if $use_fast_arrays
          (let ((type (if (symbolp (cadr x)) (cadr x) '$any))
                (name (car x))
                (diml (if (symbolp (cadr x)) (cddr x) (cdr x))))
@@ -1741,8 +1757,7 @@ wrapper for this."
                         (mapcar #'(lambda (dim)
                                   ;; let make_array catch bad vals
                                     (add 1 (meval dim)))
-                                diml)))))
-	((symbolp (car x))
+                                diml))))
 	 (let ((compp (assoc (cadr x) '(($complete . t) ($integer . fixnum) ($fixnum . fixnum)
 					($float . flonum) ($flonum . flonum)))))
 	   (let ((fun (car x))
@@ -1761,8 +1776,7 @@ wrapper for this."
 		    (wna-err '$array))
 		   ((> (length diml) 5)
 		    (merror (intl:gettext "array: number of dimensions must be 5 or less; found: ~M") (length diml)))
-		   ((member nil (mapcar #'(lambda (u) (eq (ml-typep u) 'fixnum)) diml)
-			    :test #'eq)
+		   ((member nil (mapcar #'fixnump diml) :test #'eq)
 		    (merror (intl:gettext "array: all dimensions must be integers."))))
 	     (setq diml (mapcar #'1+ diml))
 	     (setq new (if compp fun (gensym)))
@@ -1789,9 +1803,9 @@ wrapper for this."
 				   (merror (intl:gettext "array: existing elements must be ~M; found: ~M") compp (cdar items)))
 			       (setf (apply #'aref (symbol-array new) (caar items))
 				     (cdar items)))
-			    (if (or (not (eq (ml-typep (car x)) 'fixnum))
-				    (< (car x) 0)
-				    (not (< (car x) (car y))))
+			    (if (or (not (fixnump (car x)))
+                                   (< (car x) 0)
+                                   (not (< (car x) (car y))))
 				(merror (intl:gettext "array: index must be nonnegative integer less than ~M; found: ~M") (car y) (car x))))))
 		      (mremprop fun 'hashar)
 		      (mputprop fun new 'array)))
@@ -1800,11 +1814,9 @@ wrapper for this."
 	       (putprop fun '$fixnum 'array-mode))
 	     (when (eq compp 'flonum)
 	       (putprop fun '$float 'array-mode))
-	     fun)))
+	     fun))))
 	(($listp (car x))
-	 (dolist (u (cdar x))
-	   (meval `(($array) ,u ,@(cdr x))))
-	 (car x))
+	 (cons '(mlist) (mapcar #'(lambda (u) (meval `(($array) ,u ,@(cdr x)))) (cdar x))))
 	(t
 	 (merror (intl:gettext "array: first argument must be a symbol or a list; found: ~M") (car x)))))
 
@@ -1862,10 +1874,10 @@ wrapper for this."
 		  (if (member fun '(mqapply $%) :test #'eq) (merror (intl:gettext "assignment: cannot assign to ~M") l))
 		  (if $use_fast_arrays
 		    (progn
-		      (format t "ARRSTORE: use_fast_arrays=true; allocate a new value hash table for ~S~%" fun)
+		      ;; (format t "ARRSTORE: use_fast_arrays=true; allocate a new value hash table for ~S~%" fun)
 		      (meval* `((mset) ,fun ,(make-equal-hash-table (cdr (mevalargs (cdr l)))))))
 		    (progn
-		      (format t "ARRSTORE: use_fast_arrays=false; allocate a new property hash table for ~S~%" fun)
+		      ;; (format t "ARRSTORE: use_fast_arrays=false; allocate a new property hash table for ~S~%" fun)
 		  (add2lnc fun $arrays)
 		  (setq ary (gensym))
 		  (mputprop fun ary 'hashar)
@@ -1885,7 +1897,7 @@ wrapper for this."
 			((not (= (length l) 2))
 			 (merror (intl:gettext "assignment: matrix row must have one index; found: ~M") (cons '(mlist) (cdr l)))))
 		  (let ((index (meval (cadr l))))
-		    (cond ((not (eq (ml-typep index) 'fixnum))
+		    (cond ((not (fixnump index))
 			   (merror (intl:gettext "assignment: matrix row index must be an integer; found: ~M") index))
 			  ((and (> index 0) (< index (length ary)))
 			   (rplaca (nthcdr (1- index) (cdr ary)) r))
@@ -1950,8 +1962,7 @@ wrapper for this."
 		     `((mlist) ,@(mapcar #'1- (cdr (arraydims (mget ary 'array)))))
 		     `((mlist) ,@sub))
 	   ret))
-    (cond ((or (null x) (and (eq (ml-typep (car x)) 'fixnum)
-			     (or (< (car x) 0) (not (< (car x) (car y))))))
+    (cond ((or (null x) (and (fixnump (car x)) (or (< (car x) 0) (not (< (car x) (car y))))))
 	   (setq y nil x (cons nil t)))
 	  ((not (fixnump (car x)) )
 	   (if fixpp (setq y nil x (cons nil t)) (setq ret nil))))))
@@ -2071,6 +2082,9 @@ wrapper for this."
   (list '(lambda) (cons '(mlist) args) body))
 
 (defun mdefchk (fun args ary mqdef)
+  (let ((dup (find-duplicate args :test #'eq :key #'mparam)))
+    (when dup
+      (merror (intl:gettext "define: ~M occurs more than once in the parameter list") (mparam dup))))
   (do ((l args (cdr l)) (mfex) (mlex))
       ((null l) (and mfex (not mqdef) (mputprop fun mfex 'mfexprp))
        (and mlex (not mqdef) (mputprop fun mlex 'mlexprp)))
@@ -2084,10 +2098,10 @@ wrapper for this."
 					(mdefparam (cadr (cadar l)))
 					(setq mfex t)))
 			       (setq mlex t))))))
-	(merror (intl:gettext "define: in definition of ~:M, found bad argument ~M") fun (car l)))))
+	(merror (intl:gettext "define: in definition of ~:M, parameter must be a symbol and must not be a system constant; found: ~M") fun (car l)))))
 
 (defun mdefparam (x)
-  (and (atom x) (not (maxima-constantp x)) (not (stringp x))))
+  (and (symbolp x) (not (get x 'sysconst))))
 
 (defun mdeflistp (l)
   (and (null (cdr l)) ($listp (car l)) (cdar l) (null (cddar l))))
@@ -2250,7 +2264,6 @@ wrapper for this."
   (setq prog (cdr prog))
   (let (vars vals (mlocp t))
     (if ($listp (car prog)) (setq vars (cdar prog) prog (cdr prog)))
-    (setq loclist (cons nil loclist))
     (do ((l vars (cdr l))) ((null l) (setq vals vars))
       (if (not (atom (car l))) (return (setq vals t))))
     (if (eq vals t)
@@ -2262,26 +2275,34 @@ wrapper for this."
 					 v))))
 			   vars)
 	      vars (mapcar #'(lambda (v) (if (atom v) v (cadr v))) vars)))
-    (mbinding (vars vals)
-	      (do ((prog prog (cdr prog)) (mprogp prog)
-		   (bindl bindlist) (val '$done) (retp) (x) ($%% '$%%))
-		  ((null prog) (munlocal) val)
-		(cond ((atom (car prog))
-		       (if (null (cdr prog))
-			   (setq retp t val (meval (car prog)))))
-		      ((null (setq x (catch 'mprog
-				       (prog2 (setq val (setq $%% (meval (car prog))))
-					   nil)))))
-		      ((not (eq bindl bindlist))
-		       (if (not (atom x))
-                 ;; DUNNO WHAT'S "ILLEGAL" HERE
-			   (merror (intl:gettext "block: illegal 'return': ~M") (car x))
-                 ;; DUNNO WHAT'S "ILLEGAL" HERE
-			   (merror (intl:gettext "block: illegal 'go': ~M") x)))
-		      ((not (atom x)) (setq retp t val (car x)))
-		      ((not (setq prog (member x mprogp :test #'equal)))
-		       (merror (intl:gettext "block: no such tag: ~:M") x)))
-		(if retp (setq prog '(nil)))))))
+    (let ((dup (find-duplicate vars :test #'eq)))
+      (when dup
+        (merror (intl:gettext "block: ~M occurs more than once in the variable list") dup)))
+    (setq loclist (cons nil loclist))
+    ; Ensure that MUNLOCAL gets called so that we don't leak local
+    ; properties if we run into an error
+    (unwind-protect
+	(mbinding (vars vals)
+		  (do ((prog prog (cdr prog)) (mprogp prog)
+		       (bindl bindlist) (val '$done) (retp) (x) ($%% '$%%))
+		      ((null prog) val)
+		    (cond ((atom (car prog))
+			   (if (null (cdr prog))
+			       (setq retp t val (meval (car prog)))))
+			  ((null (setq x (catch 'mprog
+					   (prog2 (setq val (setq $%% (meval (car prog))))
+					       nil)))))
+			  ((not (eq bindl bindlist))
+			   (if (not (atom x))
+			       ;; DUNNO WHAT'S "ILLEGAL" HERE
+			       (merror (intl:gettext "block: illegal 'return': ~M") (car x))
+			       ;; DUNNO WHAT'S "ILLEGAL" HERE
+			       (merror (intl:gettext "block: illegal 'go': ~M") x)))
+			  ((not (atom x)) (setq retp t val (car x)))
+			  ((not (setq prog (member x mprogp :test #'equal)))
+			   (merror (intl:gettext "block: no such tag: ~:M") x)))
+		    (if retp (setq prog '(nil)))))
+      (munlocal))))
 
 (defmfun mreturn (&optional (x nil) &rest args)
   (cond 
